# Credits

## Development Lead

* Andrea Mucci <andrea@clariteia.com>

## Core Devs

* Sergio Garcia Prado <sergio.garcia@clariteia.com>
* Vladyslav Fenchak <vladyslav.fenchak@clariteia.com>
* Alberto Amigo Alonso <alberto.amigo@clariteia.com>

## Contributors

None yet. Why not be the first?
